#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
WavX 音频分析模块

包含各种音频分析功能的模块集合
"""

from . import amplitude
from . import spectrogram
from . import waveform

# Export commonly used functions for convenience
from .amplitude import analyze_amplitude, print_amplitude_info
from .spectrogram import analyze_spectrogram, display_spectrogram
from .waveform import analyze_waveform, display_waveform
